==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemPicnicBasket.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.PicnicBasketRender;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.ItemContainerTooltip;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerFactory;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2371;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_3222;
import net.minecraft.class_5632;
import net.minecraft.class_756;
import net.minecraft.class_9288;
import net.minecraft.class_9334;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;

public class ItemPicnicBasket extends class_1747 implements ExtendedScreenHandlerFactory<class_1799>, IItemRenderer {
    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new PicnicBasketRender(minecraft.method_31975(), minecraft.method_31974());
    }

    private static final int PICNIC_BASKET_SIZE = 9;

    public ItemPicnicBasket(class_2248 block) {
        super(block, (new class_1793()).method_7889(1));
    }

    public static ItemStackHandler getContainer(class_1799 stack) {
        ItemStackHandler handler = new ItemStackHandler(PICNIC_BASKET_SIZE);
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_9288 container = stack.method_57824(class_9334.field_49622);
            if (container != null) {
                List<class_1799> itemStacks = container.method_57489().toList();
                for (int i = 0; i < container.method_57489().count(); i++) {
                    handler.setStackInSlot(i, itemStacks.get(i));
                }
            }
        }
        return handler;
    }

    public static void setContainer(class_1799 stack, ItemStackHandler itemStackHandler) {
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_2371<class_1799> items = class_2371.method_10213(PICNIC_BASKET_SIZE, class_1799.field_8037);
            for (int i = 0; i < itemStackHandler.getSlots(); i++) {
                items.set(i, itemStackHandler.getStackInSlot(i));
            }
            class_9288 container = class_9288.method_57493(items);
            stack.method_57379(class_9334.field_49622, container);
        }
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808 && playerIn instanceof class_3222 serverPlayer) {
            serverPlayer.method_17355(this/*, data -> ItemStack.STREAM_CODEC.encode(data, serverPlayer.getMainHandItem())*/);
            return class_1271.method_22427(playerIn.method_6047());
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    @Override
    public Optional<class_5632> method_32346(class_1799 stack) {
        ItemStackHandler container = getContainer(stack);
        return Optional.of(new ItemContainerTooltip(container));
    }

    @Override
    public String method_7876() {
        return "item.touhou_little_maid.picnic_basket";
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471(this.method_7876());
    }

    @Nullable
    @Override
    public class_1703 createMenu(int containerId, class_1661 playerInventory, class_1657 player) {
        return new PicnicBasketContainer(containerId, playerInventory, player.method_6047());
    }

    @Override
    public class_1799 getScreenOpeningData(class_3222 player) {
        return player.method_6047();
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.4.3-neo1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemPicnicBasket.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.PicnicBasketRender;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.inventory.container.other.PicnicBasketContainer;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.ItemContainerTooltip;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.screenhandler.v1.ExtendedScreenHandlerFactory;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1703;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2371;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_5632;
import net.minecraft.class_756;
import net.minecraft.class_9288;
import net.minecraft.class_9334;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;

public class ItemPicnicBasket extends class_1747 implements ExtendedScreenHandlerFactory<class_1799>, IItemRenderer {
    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        return PicnicBasketRender.INSTANCE.get();
    }

    private static final int PICNIC_BASKET_SIZE = 9;

    public ItemPicnicBasket(class_2248 block) {
        super(block, (new class_1793()).method_7889(1));
    }

    public static ItemStackHandler getContainer(class_1799 stack) {
        ItemStackHandler handler = new ItemStackHandler(PICNIC_BASKET_SIZE);
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_9288 container = stack.method_57824(class_9334.field_49622);
            if (container != null) {
                List<class_1799> itemStacks = container.method_57489().toList();
                for (int i = 0; i < container.method_57489().count(); i++) {
                    handler.setStackInSlot(i, itemStacks.get(i));
                }
            }
        }
        return handler;
    }

    public static void setContainer(class_1799 stack, ItemStackHandler itemStackHandler) {
        if (stack.method_7909() == InitItems.PICNIC_BASKET) {
            class_2371<class_1799> items = class_2371.method_10213(PICNIC_BASKET_SIZE, class_1799.field_8037);
            for (int i = 0; i < itemStackHandler.getSlots(); i++) {
                items.set(i, itemStackHandler.getStackInSlot(i));
            }
            class_9288 container = class_9288.method_57493(items);
            stack.method_57379(class_9334.field_49622, container);
        }
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 worldIn, class_1657 playerIn, class_1268 handIn) {
        if (handIn == class_1268.field_5808 && playerIn instanceof class_3222 serverPlayer) {
            serverPlayer.method_17355(this/*, data -> ItemStack.STREAM_CODEC.encode(data, serverPlayer.getMainHandItem())*/);
            return class_1271.method_22427(playerIn.method_6047());
        }
        return super.method_7836(worldIn, playerIn, handIn);
    }

    @Override
    public Optional<class_5632> method_32346(class_1799 stack) {
        ItemStackHandler container = getContainer(stack);
        return Optional.of(new ItemContainerTooltip(container));
    }

    @Override
    public String method_7876() {
        return "item.touhou_little_maid.picnic_basket";
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471(this.method_7876());
    }

    @Nullable
    @Override
    public class_1703 createMenu(int containerId, class_1661 playerInventory, class_1657 player) {
        return new PicnicBasketContainer(containerId, playerInventory, player.method_6047());
    }

    @Override
    public class_1799 getScreenOpeningData(class_3222 player) {
        return player.method_6047();
    }
}
